@@ -154,7 +154,6 @@ Convert-ASCII-Armour,dev-perl/convert-ascii-armour
 Convert-PEM,dev-perl/convert-pem
 DBIx-SearchBuilder,dev-perl/dbix-searchbuilder
 Data-Buffer,dev-perl/data-buffer
-Date-Manip,dev-perl/DateManip
 Digest-BubbleBabble,dev-perl/digest-bubblebabble
 Digest-MD2,dev-perl/digest-md2
 ExtUtils-PkgConfig,dev-perl/extutils-pkgconfig
@@ -172,24 +171,15 @@ Gtk2-Spell,dev-perl/gtk2-spell
 Gtk2-TrayIcon,dev-perl/gtk2-trayicon
 Gtk2-TrayManager,dev-perl/gtk2-traymanager
 Image-ExifTool,media-libs/exiftool
-Math-Pari,dev-perl/math-pari
-MogileFS-Server,dev-perl/mogilefs-server
 NTLM,dev-perl/Authen-NTLM
 OLE-Storage_Lite,dev-perl/OLE-StorageLite
-Ogg-Vorbis-Header,dev-perl/ogg-vorbis-header
 Padre,app-editors/padre
 PathTools,virtual/perl-File-Spec
-Perl-Tidy,dev-perl/perltidy
 Regexp-Common,dev-perl/regexp-common
-Set-Scalar,dev-perl/set-scalar
 Snapback2,app-backup/snapback2
-String-CRC32,dev-perl/string-crc32
 Text-Template,dev-perl/text-template
 Text-Wrapper,dev-perl/text-wrapper
 Tie-EncryptedHash,dev-perl/tie-encryptedhash
-Time-Period,dev-perl/Period
-Tk,dev-perl/perl-tk
-Wx,dev-perl/wxperl
 XML-XSH2,app-editors/XML-XSH2
 YAML,dev-perl/yaml
 ack,sys-apps/ack
